<?php
session_start();
if (!isset($_COOKIE['admin'])) {
  echo "<p style='padding:2rem;font-family:sans-serif;color:red;'>Nepovolený přístup. Přihlaste se jako administrátor z hlavní stránky.</p>";
  exit;
}
?>

<!DOCTYPE html>
<html lang="cs">
<head>
  <meta charset="UTF-8" />
  <title>SportKatalog – Admin</title>
  <link rel="stylesheet" href="style.css" />
  <style>
    body { padding: 2rem; font-family: 'Inter', sans-serif; }
    h1 { margin-bottom: 0.5rem; }
    table { width: 100%; border-collapse: collapse; margin-bottom: 2rem; }
    th, td { border: 1px solid #ccc; padding: 0.5rem; text-align: left; }
    form input { padding: 0.5rem; margin: 0.25rem 0; width: 100%; }
    button { margin-right: 0.5rem; }
    .admin-form { max-width: 500px; margin-top: 2rem; }
    .back-link-admin {
      display: inline-block;
      margin-bottom: 1.5rem;
      color: #0056b3;
      text-decoration: none;
      font-weight: bold;
      font-size: 1rem;
      background: #eaeaea;
      padding: 0.4rem 0.8rem;
      border-radius: 6px;
      transition: background 0.3s ease;
    }
    .back-link-admin:hover {
      background: #d5d5d5;
    }
  </style>
</head>
<body>
  <script>
    if (localStorage.getItem('admin') !== '1') {
      alert('Nejste přihlášen jako administrátor.');
      window.location.href = 'index.html';
    }
  </script>

  <h1>Administrace produktů</h1>
  <a href="index.html" class="back-link-admin">← Zpět na hlavní stránku</a>

  <table id="product-table">
    <thead>
      <tr><th>Název</th><th>Kategorie</th><th>Obrázek</th><th>Akce</th></tr>
    </thead>
    <tbody></tbody>
  </table>

  <h2 id="form-title">Přidat produkt</h2>
  <form id="product-form" class="admin-form">
    <input type="hidden" id="edit-index" value="">
    <label>Název produktu: <input type="text" id="name" required></label><br>
    <label>Kategorie: <input type="text" id="category" required></label><br>
    <label>Obrázek (cesta): <input type="text" id="image" required></label><br>
    <button type="submit">Uložit</button>
    <button type="button" onclick="resetForm()">Zrušit</button>
  </form>

  <script>
    let produkty = [];

    function loadData() {
      fetch('api.php?action=list')
        .then(res => res.json())
        .then(data => {
          produkty = data;
          renderTable();
        });
    }

    function renderTable() {
      const tbody = document.querySelector('#product-table tbody');
      tbody.innerHTML = '';
      produkty.forEach((p, index) => {
        tbody.innerHTML += `
          <tr>
            <td>${p.name}</td>
            <td>${p.category}</td>
            <td>${p.image}</td>
            <td>
              <button onclick="editProduct(${index})">Upravit</button>
              <button onclick="deleteProduct(${index})">Smazat</button>
            </td>
          </tr>`;
      });
    }

    function editProduct(index) {
      const p = produkty[index];
      document.getElementById('edit-index').value = index;
      document.getElementById('name').value = p.name;
      document.getElementById('category').value = p.category;
      document.getElementById('image').value = p.image;
      document.getElementById('form-title').textContent = 'Upravit produkt';
    }

    function deleteProduct(index) {
      if (!confirm('Opravdu chcete smazat tento produkt?')) return;
      fetch('api.php?action=delete', {
        method: 'POST',
        body: JSON.stringify({ index })
      }).then(() => loadData());
    }

    function resetForm() {
      document.getElementById('product-form').reset();
      document.getElementById('edit-index').value = '';
      document.getElementById('form-title').textContent = 'Přidat produkt';
    }

    document.getElementById('product-form').addEventListener('submit', e => {
      e.preventDefault();
      const product = {
        name: document.getElementById('name').value,
        category: document.getElementById('category').value,
        image: document.getElementById('image').value
      };
      const index = document.getElementById('edit-index').value;

      const action = index === '' ? 'add' : 'edit';
      const payload = index === '' ? product : { index: parseInt(index), ...product };

      fetch(`api.php?action=${action}`, {
        method: 'POST',
        body: JSON.stringify(payload)
      }).then(() => {
        resetForm();
        loadData();
      });
    });

    loadData();
  </script>
</body>
</html>
